Tutorials
=========

Check out the :bdg-link-primary:`main demo <tutorials/notebooks/main_demo.ipynb>` for a quick walkthrough of important nnsight functionality. You can also check out more tutorials for the package below! 

.. grid:: 2
   :gutter: 3

   .. grid-item-card::  Basics
      :link: tutorials/main_demo.ipynb

      Walk through the basic functionality of the package.

   .. grid-item-card::  Features
      :link: features

      Learn some more advanced features of the package.
   
   .. grid-item-card::  Toolkit

      Familiarize yourself with the tools that come with the package. (Coming soon!)

   .. grid-item-card::  Papers

      See how nnsight can be applied through key papers in interpretability. (Coming soon!)

      


.. toctree::
   :hidden:
   :maxdepth: 1

   tutorials/main_demo.ipynb
   tutorials/basics
   tutorials/features